@@ -51,7 +51,7 @@ sub new {
     return $self;
 }
 
-sub list_downloaders {
+sub get_downloaders {
     my $self = shift;
 
     my $parameters = { 'type' => 0, };
@@ -75,7 +75,7 @@ sub get_downloader {
     
     my $name = shift;
 
-    my @downloaders = grep { $_->{'name'} eq $name } $self->list_downloaders();
+    my @downloaders = grep { $_->{'name'} eq $name } $self->get_downloaders();
     die "No such Downloader named >>$name<<" unless @downloaders;
     return shift @downloaders;
 }
@@ -324,14 +324,14 @@ WWW::Xunlei - Perl API For Official Xunlei Remote API.
 
 =head1 VERSION
 
-version 0.06
+version 0.1
 
 =head1 SYNOPSIS
 
     use WWW::Xunlei;
     my $client = WWW::Xunlei->new("username", "password");
     # use the first downloader;
-    my $downloader = $client->list_downloaders()->[0];
+    my $downloader = $client->get_downloaders()->[0];
     # create a remote task;
     $downloader->create_task("http://www.cpan.org/src/5.0/perl-5.22.0.tar.gz");
 
@@ -352,12 +352,12 @@ C<cookie_file> option. The default session expire time is 7 days.
 Bind a new downloader with a activation code. The new downloader's name can
  be defined with the optional argument C<$name>.
 
-=head2 list_downloaders
+=head2 get_downloaders
 
 List all the downloaders binding with your account. Return a list of
 C<WWW::Xunlei::Downloader> object.
 
-==method list_downloader($name)
+=head2 get_downloader($name)
 
 Get the downloader of which the name is $name. 
 Return a C<WWW::Xunlei::Downloader> object.
